@@ -11,13 +11,13 @@ from hydroqc.contract.outage import Outage
 from hydroqc.hydro_api.client import HydroClient
 from hydroqc.logger import get_logger
 from hydroqc.types import (
-    ConsoAnnualTyping,
-    ConsoDailyTyping,
-    ConsoHourlyTyping,
-    ConsoMonthlyTyping,
+    ConsumpAnnualTyping,
+    ConsumpDailyTyping,
+    ConsumpHourlyTyping,
+    ConsumpMonthlyTyping,
+    ContractTyping,
     OutageListTyping,
     PeriodDataTyping,
-    listeContratModelTyping,
 )
 from hydroqc.utils import EST_TIMEZONE
 
@@ -26,16 +26,21 @@ P = ParamSpec("P")
 
 
 def check_period_data_present(
-    method: Callable[..., None | str | bool | float]
-) -> Callable[..., None | str | bool | float]:
+    method: Callable[..., None | str | bool | float | PeriodDataTyping]
+) -> Callable[..., None | str | bool | float | PeriodDataTyping]:
     """Check if contract's data are present."""
 
-    def wrapper(contract: "Contract") -> None | str | bool | float:
-        if len(contract._all_period_data):
-            return method(contract)
-
-        contract._logger.warning("You need to call get_latest_period_info method first")
-        return None
+    def wrapper(contract: "Contract") -> None | str | bool | float | PeriodDataTyping:
+        if not hasattr(contract, "_all_period_data"):
+            contract._logger.warning("You need to call get_period_info method first")
+            return None
+        if not contract._all_period_data:
+            contract._logger.info(
+                "It seems Hydro-Québec didn't provided some data. "
+                "Maybe you did a rate change recently. "
+                "This message should disappear at the beginning of the next bill period."
+            )
+        return method(contract)
 
     return wrapper
 
@@ -46,11 +51,16 @@ def check_info_data_present(
     """Check if contract's data are present."""
 
     def wrapper(contract: "Contract") -> None | str | bool | float | date:
-        if hasattr(contract, "_raw_info_data"):
-            return method(contract)
-
-        contract._logger.warning("You need to call get_info method first")
-        return None
+        if not hasattr(contract, "_raw_info_data"):
+            contract._logger.warning("You need to call get_info method first")
+            return None
+        if not contract._raw_info_data:
+            contract._logger.info(
+                "It seems Hydro-Québec didn't provided some data. "
+                "Maybe you did a rate change recently. "
+                "This message should disappear at the beginning of the next bill period."
+            )
+        return method(contract)
 
     return wrapper
 
@@ -61,11 +71,19 @@ def check_annual_data_present(
     """Check if contract's data are present."""
 
     def wrapper(contract: "Contract") -> None | str | bool | float | date:
-        if hasattr(contract, "_annual_info_data"):
-            return method(contract)
-
-        contract._logger.warning("You need to call get_annual_consumption method first")
-        return None
+        if not hasattr(contract, "_annual_info_data"):
+            contract._logger.warning(
+                "You need to call get_annual_consumption method first"
+            )
+            return None
+        if not contract._annual_info_data:
+            contract._logger.info(
+                "It seems Hydro-Québec didn't provided some data. "
+                "Maybe you did a rate change recently. "
+                "This message should disappear at the beginning of the next bill period."
+            )
+            return None
+        return method(contract)
 
     return wrapper
 
@@ -96,9 +114,10 @@ class Contract(ABC):
     _rate_option_code: str
     _meter_id: str
     _address: str
-    _raw_info_data: listeContratModelTyping
-    _annual_info_data: ConsoAnnualTyping
+    _raw_info_data: ContractTyping
+    _annual_info_data: ConsumpAnnualTyping
     _outages_data: OutageListTyping
+    _all_period_data: list[PeriodDataTyping]
 
     def __init__(
         self,
@@ -121,7 +140,6 @@ class Contract(ABC):
         self._no_contrat: str = contract_id
         self._hydro_client: HydroClient = hydro_client
         self._address: str = ""
-        self._all_period_data: list[PeriodDataTyping] = []
         self._outages: list[Outage] = []
 
     # Main attributes
@@ -185,7 +203,7 @@ class Contract(ABC):
         return self._raw_info_data["idLieuConsommation"]
 
     # Main methods
-    async def get_info(self) -> listeContratModelTyping:
+    async def get_info(self) -> ContractTyping:
         """Fetch info about this contract."""
         self._logger.debug("Getting contract info")
         self._raw_info_data = await self._hydro_client.get_contract_info(
@@ -203,11 +221,11 @@ class Contract(ABC):
         self._logger.debug("Got contract periods info")
         return self._all_period_data
 
-    def get_latest_period_info(self) -> PeriodDataTyping | dict[None, None]:
+    @property
+    @check_period_data_present
+    def latest_period_info(self) -> PeriodDataTyping:
         """Fetch latest period info."""
-        if self._all_period_data:
-            return self._all_period_data[0]
-        return {}
+        return self._all_period_data[0]
 
     async def refresh_outages(self) -> None:
         """Fetch contract outages."""
@@ -237,27 +255,27 @@ class Contract(ABC):
         return None
 
     # Consumption methods
-    async def get_today_hourly_consumption(self) -> ConsoHourlyTyping:
+    async def get_today_hourly_consumption(self) -> ConsumpHourlyTyping:
         """Fetch hourly consumption for today."""
         return await self._hydro_client.get_today_hourly_consumption(
             self.applicant_id, self.customer_id, self.contract_id
         )
 
-    async def get_hourly_consumption(self, date_wanted: str) -> ConsoHourlyTyping:
+    async def get_hourly_consumption(self, date_wanted: date) -> ConsumpHourlyTyping:
         """Fetch hourly consumption for a date."""
         return await self._hydro_client.get_hourly_consumption(
             self.applicant_id, self.customer_id, self.contract_id, date_wanted
         )
 
     async def get_daily_consumption(
-        self, start_date: str, end_date: str
-    ) -> ConsoDailyTyping:
+        self, start_date: date, end_date: date
+    ) -> ConsumpDailyTyping:
         """Fetch daily consumption."""
         return await self._hydro_client.get_daily_consumption(
             self.applicant_id, self.customer_id, self.contract_id, start_date, end_date
         )
 
-    async def get_today_daily_consumption(self) -> ConsoDailyTyping:
+    async def get_today_daily_consumption(self) -> ConsumpDailyTyping:
         """TODO ????.
 
         .. todo::
@@ -265,17 +283,15 @@ class Contract(ABC):
         """
         today = datetime.today().astimezone(EST_TIMEZONE)
         yesterday = today - timedelta(days=1)
-        start_date = yesterday.strftime("%Y-%m-%d")
-        end_date = today.strftime("%Y-%m-%d")
-        return await self.get_daily_consumption(start_date, end_date)
+        return await self.get_daily_consumption(yesterday, today)
 
-    async def get_monthly_consumption(self) -> ConsoMonthlyTyping:
+    async def get_monthly_consumption(self) -> ConsumpMonthlyTyping:
         """Fetch monthly consumption."""
         return await self._hydro_client.get_monthly_consumption(
             self.applicant_id, self.customer_id, self.contract_id
         )
 
-    async def get_annual_consumption(self) -> ConsoAnnualTyping:
+    async def get_annual_consumption(self) -> ConsumpAnnualTyping:
         """Fetch annual consumption."""
         self._annual_info_data = await self._hydro_client.get_annual_consumption(
             self.applicant_id, self.customer_id, self.contract_id
@@ -285,8 +301,8 @@ class Contract(ABC):
     # CSV methods
     async def get_daily_energy(
         self,
-        start_date: str,
-        end_date: str,
+        start_date: date,
+        end_date: date,
         raw_output: bool = False,
     ) -> Iterator[list[str | int | float]] | StringIO:
         """Get daily energy and power data on a specific date range.
@@ -306,8 +322,8 @@ class Contract(ABC):
 
     async def get_hourly_energy(
         self,
-        start_date: str,
-        end_date: str,
+        start_date: date,
+        end_date: date,
         raw_output: bool = False,
     ) -> Iterator[list[str | int | float]] | StringIO:
         """Get hourly energy on a specific date range.
